@@ -1,11 +1,8 @@
 package Dancer2::Template::Caribou;
-BEGIN {
-  $Dancer2::Template::Caribou::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Dancer2::Template::Caribou::VERSION = '0.2.1';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Template::Caribou wrapper for Dancer2
+$Dancer2::Template::Caribou::VERSION = '1.0.0';
+# TODO move away from Dancer2::Test
 
 
 use strict;
@@ -33,11 +30,6 @@ has layout_class => (
     default => sub { { } },
 );
 
-has auto_reload => (
-    is => 'ro',
-    default => sub { 0 },
-);
-
 has namespace => (
     is => 'ro',
     lazy => 1,
@@ -83,15 +75,12 @@ package $name;
 use Moose::Role;
 use Template::Caribou;
 
-with 'Template::Caribou';
-
 # line 1 "$bou"
 
 $inner;
 
 with 'Template::Caribou::Files' => {
     dirs => [ '$bou_dir' ],
-    auto_reload => 1,
 };
 
 1;
@@ -116,16 +105,12 @@ sub generate_view_class {
 
     my $inner = path($bou)->slurp;
 
-    my $auto_reload = $self->auto_reload;
-
     eval qq{
 package $name;
 
-use Moose;
 use Template::Caribou;
 
 with qw/
-    Template::Caribou
     Dancer2::Template::Caribou::DancerVariables
 /;
 
@@ -144,7 +129,6 @@ $inner;
 
 with 'Template::Caribou::Files' => {
     dirs => [ '$bou_dir' ],
-    auto_reload => $auto_reload,
 };
 
 1;
@@ -174,11 +158,11 @@ sub render {
         $c =~ s#/#::#g;
         $c = join '::', $self->namespace, $c;
         die "template '$template' not found\n"
-            unless eval { $c->DOES('Template::Caribou') };
+            unless eval { $c->DOES('Template::Caribou::Role') };
         $class = $c;
     }
 
-    if ( my $lay = $self->layout || $self->context->app->config->{layout} ) {
+    if ( my $lay = $self->layout || $self->settings->{layout} ) {
         my $role = $self->layout_class->{$lay}
             or die "layout '$lay' not defined\n";
 
@@ -186,7 +170,7 @@ sub render {
         )
     }
 
-    return $class->new( context => $self->context, app => $self->context->app, %$tokens)->render('page');
+    return $class->new( request => $self->request,  %$tokens)->render('page');
 }
 
 1;
@@ -195,13 +179,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer2::Template::Caribou - Template::Caribou wrapper for Dancer2
 
 =head1 VERSION
 
-version 0.2.1
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -212,7 +198,6 @@ version 0.2.1
       template:
         Caribou:
           namespace:    MyApp::View
-          auto_reload:  1
 
 
     # and then in the application
@@ -299,11 +284,14 @@ above, we could change it into
 
 
     # in /views/howdie/page
-    html {
-        head { title { 'My App' } };
-        body {
-            h1 { 'howdie ' . $self->name . '!' };
-        };
+    sub {
+        my $self = shift;
+        html {
+            head { title { 'My App' } };
+            body {
+                h1 { 'howdie ' . $self->name . '!' };
+            };
+        }
     }
 
 =head3 Layouts as roles
@@ -346,12 +334,6 @@ the template class. Again, to take our example:
 The namespace under which the Caribou classes are created.
 defaults to C<Dancer2::View>.
 
-=item auto_reload
-
-If set to C<true>, the Caribou object will verify if any of the 
-template files have changed before rendering and, if that's the case,
-will self-update. Defaults to C<false>.
-
 =back
 
 =head1 CONVENIENCE ATTRIBUTES AND METHODS
@@ -364,11 +346,9 @@ classes, you simply have to apply the role to have access to the same niftiness.
 
     package Dancer2::View::MyView;
 
-    use Moose;
     use Template::Caribou;
 
     with qw/ 
-        Template::Caribou 
         Dancer2::Template::Caribou::DancerVariables 
     /;
 
