@@ -1,12 +1,7 @@
 package Dancer2::Template::Caribou::DancerVariables;
-BEGIN {
-  $Dancer2::Template::Caribou::DancerVariables::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Dancer2::Template::Caribou::DancerVariables::VERSION = '0.2.1';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Role providing Dancer attributes to the template objects
-
+$Dancer2::Template::Caribou::DancerVariables::VERSION = '1.0.0';
 
 use strict;
 use warnings;
@@ -14,13 +9,13 @@ use warnings;
 use Moose::Role;
 
 
-has "context" => (
+has "request" => (
     is => 'ro',
 );
 
 
 sub uri_for {
-    $_[0]->context->request->uri_for($_[1]);
+    $_[0]->request->uri_for($_[1]);
 }
 
 1;
@@ -29,13 +24,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer2::Template::Caribou::DancerVariables - Role providing Dancer attributes to the template objects
 
 =head1 VERSION
 
-version 0.2.1
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -62,9 +59,9 @@ allow interactions with the L<Dancer2> application and its context.
 
 =head1 METHODS
 
-=head2 context()
+=head2 request()
 
-Returns the current L<Dancer2::Core::Context> object.
+Returns the current L<Dancer2::Core::Request> object.
 
 =head2 uri_for( $path ) 
 
